pub fn load<'a>(workspace: &'a WorkspaceIndex, dir: &Path) -> &'a MetadataExpand description
Panics
Panics when neither dir nor the workspace root has indexed metadata.
pub fn load<'a>(workspace: &'a WorkspaceIndex, dir: &Path) -> &'a MetadataPanics when neither dir nor the workspace root has indexed metadata.